"""Module that contains the argument types from the functions."""
from enum import Enum


class ArgumentTypes(Enum):
    """Argument types used with their respective values."""

    PLATFORM: str = "platform"
    """The package platform (e.g. "PyPi")."""
    PROJECT: str = "project"
    """The project name."""
    HOST: str = "host"
    """The host platform (e.g. "GitHub")."""
    OWNER: str = "owner"
    """The owner name."""
    REPO: str = "repo"
    """The repository name."""
    FILTERS: str = "filters"
    """The filters to apply."""
    SORT: str = "sort"
    """The sort to apply."""
    SEARCH: str = "search"
    """The search URI."""
    USER: str = "user"
    """The username."""
    VERSION: str = "version"
    """The version to search."""
    QUERY: str = "query"
    """The query to use."""
    NAME: str = "name"
    """The name as an argument, where applicable."""


class TailEndpoints(Enum):
    """Vantage endpoint constants of each endpoint as defined by `libraries.io <https://libraries.io>`_."""

    PLATFORMS: str = "platforms"
    """The platforms tail endpoint."""
    PROJECTS: str = "projects"
    """The projects tail endpoint."""
    CONTRIBUTORS: str = "contributors"
    """The contributors tail endpoint."""
    DEPENDENCIES: str = "dependencies"
    """The dependencies tail endpoint."""
    DEPENDENTS: str = "dependents"
    """The dependents tail endpoint."""
    DEPENDENT_REPOSITORIES: str = "dependent_repositories"
    """The dependents repositories tail endpoint."""
    SOURCERANK: str = "sourcerank"
    """The SourceRank tail endpoint."""
    REPOSITORIES: str = "repositories"
    """The repositories tail endpoint."""
    PROJECT_CONTRIBUTIONS: str = "project-contributions"
    """The project contributions tail endpoint."""
    REPOSITORY_CONTRIBUTIONS: str = "repository-contributions"
    """The repository contributions tail endpoint."""
